@@ -53,7 +53,7 @@ class Notes_Logic
 
   public function handlerUpdateNote ($identifier)
   {
-    $this->notifierNote ($identifier, gettext ("Note updated"));
+    //$this->notifierNote ($identifier, gettext ("Note updated"));
   }
 
   public function handlerDeleteNote ($identifier)
@@ -116,9 +116,10 @@ class Notes_Logic
 
     // Send mail to all recipients.
     $summary = $database_notes->getSummary ($identifier);
+    $passages = Filter_Books::passagesDisplayInline ($database_notes->getPassages ($identifier));
     $contents = $database_notes->getContents ($identifier);
     foreach ($recipients as $recipient) {
-      $database_mail->send ($recipient, "$label - $summary", $contents);
+      $database_mail->send ($recipient, "$label | $passages | $summary", $contents);
     }
   }
 }  
